==> ejc-jlprogress-impl-3.0.0-20240507.101713-23-sources.jar: com/ejianc/business/jlprogress/order/bean/CheckDetailEntity.java <==
package com.ejianc.business.jlprogress.order.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 订单及运单-交付验收单-子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_order_check_detail")
public class CheckDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="check_id")
    private Long checkId; // 主表ID
    @TableField(value="material_id")
    private Long materialId; // 材料ID
    @TableField(value="material_code")
    private String materialCode; // 材料code
    @TableField(value="material_name")
    private String materialName; // 材料名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 材料分类ID
    @TableField(value="material_type_code")
    private String materialTypeCode; // 材料分类code
    @TableField(value="material_type_name")
    private String materialTypeName; // 材料分类名称
    @TableField(value="spec")
    private String spec; // 材料规格
    @TableField(value="model")
    private String model; // 材料型号
    @TableField(value="unit")
    private String unit; // 材料主单位
    @TableField(value="assist_unit")
    private String assistUnit; // 材料辅单位
    @TableField(value="material_num")
    private BigDecimal materialNum; // 实发主数量
    @TableField(value="material_assist_num")
    private BigDecimal materialAssistNum; // 实发数量
    @TableField(value="source_type")
    private Integer sourceType; // 数据来源：1-物料参照，2-产品出库单
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public String getAssistUnit() {
        return assistUnit;
    }

    public void setAssistUnit(String assistUnit) {
        this.assistUnit = assistUnit;
    }
    public BigDecimal getMaterialNum() {
        return materialNum;
    }

    public void setMaterialNum(BigDecimal materialNum) {
        this.materialNum = materialNum;
    }
    public BigDecimal getMaterialAssistNum() {
        return materialAssistNum;
    }

    public void setMaterialAssistNum(BigDecimal materialAssistNum) {
        this.materialAssistNum = materialAssistNum;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-jlprogress-impl-3.0.0-20240617.060953-163-sources.jar: com/ejianc/business/jlprogress/order/bean/CheckDetailEntity.java <==
package com.ejianc.business.jlprogress.order.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 订单及运单-交付验收单-子表
 *
 * @author generator
 */
@TableName("ejc_order_check_detail")
public class CheckDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "check_id")
    private Long checkId; // 主表ID
    @TableField(value = "material_id")
    private Long materialId; // 材料ID
    @TableField(value = "material_code")
    private String materialCode; // 材料code
    @TableField(value = "material_name")
    private String materialName; // 材料名称
    @TableField(value = "material_type_id")
    private Long materialTypeId; // 材料分类ID
    @TableField(value = "material_type_code")
    private String materialTypeCode; // 材料分类code
    @TableField(value = "material_type_name")
    private String materialTypeName; // 材料分类名称
    @TableField(value = "spec")
    private String spec; // 材料规格
    @TableField(value = "model")
    private String model; // 材料型号
    @TableField(value = "unit")
    private String unit; // 材料主单位
    @TableField(value = "assist_unit")
    private String assistUnit; // 材料辅单位
    @TableField(value = "material_num")
    private BigDecimal materialNum; // 实发主数量
    @TableField(value = "material_assist_num")
    private BigDecimal materialAssistNum; // 实发数量
    @TableField(value = "source_type")
    private Integer sourceType; // 数据来源：1-物料参照，2-产品出库单
    @TableField(value = "source_detail_id")
    private Long sourceDetailId; // 数据来源主表Id(只对产品出库单来源的数据生效)
    @TableField(value = "memo")
    private String memo; // 备注


    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getAssistUnit() {
        return assistUnit;
    }

    public void setAssistUnit(String assistUnit) {
        this.assistUnit = assistUnit;
    }

    public BigDecimal getMaterialNum() {
        return materialNum;
    }

    public void setMaterialNum(BigDecimal materialNum) {
        this.materialNum = materialNum;
    }

    public BigDecimal getMaterialAssistNum() {
        return materialAssistNum;
    }

    public void setMaterialAssistNum(BigDecimal materialAssistNum) {
        this.materialAssistNum = materialAssistNum;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
}
